# sky-bkg

## Description

Two sources of sky background are considered: 
* Zodiacal light 
* Earth shine


### Zodiacal light
Zodiacal light varies as a function of angular distance of the 
target from the Sun and from the ecliptic. We adopt data in Leinert
et al. (1998). 


### Earth-shine
Earth-shine varies strongly as a function of angle between the target
and the Earth lime. We adopt data from Figure 9.1 in HST/WFC3 instrument 
handbook. 

## Installation
via pip:

    pip install sky-bkg


## Usage

    from sky_bkg import sky_bkg
    
    ra = 150
    dec = 45
    time = '2019-07-01'
    zodi_wave, zodi_flux = sky_bkg.zodiacal(ra, dec, time)
    
    theta = 40
    earth_wave, earth_flux = sky_bkg.earthshine(theta)


## References
* The night sky brightness in general and for the zodiacal light in Leinert et al. 1998 A&AS, 127, 1.
* Sky background from WFC3 document
(https://hst-docs.stsci.edu/wfc3ihb/chapter-9-wfc3-exposure-time-calculation/9-7-sky-background)
* The solar spectrum is from Colina et al. 1996, download from https://cads.iiap.res.in/tools/zodiacalCalc/Documentation